@@ -56,7 +56,7 @@ def dynamic_import(module_path: str, namespace: dict, all_imports = None):
         from module_path import *
     but includes private (_xxx) names too.
     """
-    all_imports = if_none_default(all_imports,True,typ=bool)
+    all_imports = if_none_change(all_imports,True)
     if module_path:
         module = importlib.import_module(module_path)
 
@@ -72,6 +72,7 @@ def dynamic_import(module_path: str, namespace: dict, all_imports = None):
 
 def get_monorepo_root(directory=None,files=None):
     directory = directory or get_initial_caller_dir()
+    print(directory)
     py_files = get_all_py_file_paths(directory,add=True)
     sysroots = get_all_py_sysroots(directory=directory,files=py_files)
     monorepo_root = get_common_root(sysroots)
