@@ -2,7 +2,7 @@ from ..imports import *
 from .dot_utils import *
 from .extract_utils import get_all_py_file_paths
 def get_py_files(directory=None):
-    directory = directory or get_initial_caller_dir()
+    directory = directory or get_caller_dir(2)
     return get_all_py_file_paths(directory,add=True)
 def ensure_on_path(p: Path):
     s = str(p)
@@ -65,7 +65,6 @@ def get_all_py_sysroots(directory=None,files=None):
     py_files = files or get_py_files(directory=directory)
     return [compute_dotted_and_sysroot(glo)[1] for glo in py_files]
 
-get_shortest_path
 def get__imports(directory=None, sysroot=None):
     directory = directory or get_caller_dir(1)
     globs = collect_globs(directory, allowed_exts='.py')
